@@ -1,7 +1,7 @@
 app <- ShinyDriver$new("../../")
 app$snapshotInit("switchData_pred", screenshot = FALSE)
 
-app$setInputs(advOpts_cores = 4)
+app$setInputs(advOpts_cores = 4, wait_ = FALSE, values_ = FALSE)
 
 app$setInputs(navbar_ID = "Data")
 app$uploadFile(file_upload = "switchData-data.csv")
